@@ -30,6 +30,7 @@
 #include <QFontDatabase>
 #include <QPixmapCache>
 #include <QCryptographicHash>
+#include <QStyleOptionViewItem>
 
 #include <KIconLoader>
 
@@ -49,20 +50,20 @@ ContactDelegateCompact::~ContactDelegateCompact()
 
 void ContactDelegateCompact::paintContact(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    QStyleOptionViewItemV4 optV4 = option;
-    initStyleOption(&optV4, index);
+    QStyleOptionViewItem opt = option;
+    initStyleOption(&opt, index);
 
     bool isSubcontact = index.parent().isValid() && index.parent().data(KTp::RowTypeRole).toUInt() == KTp::PersonRowType;
 
     painter->save();
 
     painter->setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform | QPainter::HighQualityAntialiasing);
-    painter->setClipRect(optV4.rect);
+    painter->setClipRect(opt.rect);
 
     QStyle *style = QApplication::style();
-    style->drawPrimitive(QStyle::PE_PanelItemViewItem, &optV4, painter);
+    style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter);
 
-    QRect iconRect = optV4.rect;
+    QRect iconRect = opt.rect;
     iconRect.setSize(QSize(m_avatarSize, m_avatarSize));
     iconRect.moveTo(QPoint(iconRect.x() + m_spacing, iconRect.y() + m_spacing));
 
@@ -89,11 +90,11 @@ void ContactDelegateCompact::paintContact(QPainter *painter, const QStyleOptionV
 
     QPixmap icon = QIcon::fromTheme(index.data(KTp::ContactPresenceIconRole).toString()).pixmap(KIconLoader::SizeSmallMedium);
 
-    QRect statusIconRect = optV4.rect;
+    QRect statusIconRect = opt.rect;
 
     statusIconRect.setSize(QSize(m_presenceIconSize, m_presenceIconSize));
-    statusIconRect.moveTo(QPoint(optV4.rect.right() - (rightIconsWidth),
-                                 optV4.rect.top() + (optV4.rect.height() - m_presenceIconSize) / 2));
+    statusIconRect.moveTo(QPoint(opt.rect.right() - (rightIconsWidth),
+                                 opt.rect.top() + (opt.rect.height() - m_presenceIconSize) / 2));
 
     painter->drawPixmap(statusIconRect, icon);
 
@@ -103,10 +104,10 @@ void ContactDelegateCompact::paintContact(QPainter *painter, const QStyleOptionV
         rightIconsWidth += m_clientTypeIconSize + m_spacing;
 
         QPixmap phone = QIcon::fromTheme("phone").pixmap(m_clientTypeIconSize);
-        QRect phoneIconRect = optV4.rect;
+        QRect phoneIconRect = opt.rect;
         phoneIconRect.setSize(QSize(m_clientTypeIconSize, m_clientTypeIconSize));
-        phoneIconRect.moveTo(QPoint(optV4.rect.right() - rightIconsWidth,
-                                    optV4.rect.top() + (optV4.rect.height() - m_clientTypeIconSize) / 2));
+        phoneIconRect.moveTo(QPoint(opt.rect.right() - rightIconsWidth,
+                                    opt.rect.top() + (opt.rect.height() - m_clientTypeIconSize) / 2));
         painter->drawPixmap(phoneIconRect, phone);
     }
 
@@ -115,10 +116,10 @@ void ContactDelegateCompact::paintContact(QPainter *painter, const QStyleOptionV
         rightIconsWidth += m_clientTypeIconSize + m_spacing;
 
         const QPixmap accountIcon = QIcon::fromTheme(account->iconName()).pixmap(m_clientTypeIconSize);
-        QRect accountIconRect = optV4.rect;
+        QRect accountIconRect = opt.rect;
         accountIconRect.setSize(QSize(m_clientTypeIconSize, m_clientTypeIconSize));
-        accountIconRect.moveTo(QPoint(optV4.rect.right() - rightIconsWidth,
-                                    optV4.rect.top() + (optV4.rect.height() - m_clientTypeIconSize) / 2));
+        accountIconRect.moveTo(QPoint(opt.rect.right() - rightIconsWidth,
+                                    opt.rect.top() + (opt.rect.height() - m_clientTypeIconSize) / 2));
         painter->drawPixmap(accountIconRect, accountIcon);
     }
 
@@ -140,7 +141,7 @@ void ContactDelegateCompact::paintContact(QPainter *painter, const QStyleOptionV
 
     painter->setFont(nameFont);
 
-    QRect userNameRect = optV4.rect;
+    QRect userNameRect = opt.rect;
     userNameRect.setX(iconRect.x() + iconRect.width() + m_spacing * 2);
     userNameRect.setY(userNameRect.y() + (userNameRect.height()/2 - nameFontMetrics.height()/2));
     userNameRect.setWidth(userNameRect.width() - rightIconsWidth);
@@ -150,9 +151,9 @@ void ContactDelegateCompact::paintContact(QPainter *painter, const QStyleOptionV
     painter->drawText(userNameRect,
                       nameFontMetrics.elidedText(nameText, Qt::ElideRight, userNameRect.width()));
 
-    QRect presenceMessageRect = optV4.rect;
-    presenceMessageRect.setX(userNameRect.x() + nameFontMetrics.boundingRect(optV4.text).width() + m_spacing * 2);
-    presenceMessageRect.setWidth(optV4.rect.width() - presenceMessageRect.x() - rightIconsWidth);
+    QRect presenceMessageRect = opt.rect;
+    presenceMessageRect.setX(userNameRect.x() + nameFontMetrics.boundingRect(opt.text).width() + m_spacing * 2);
+    presenceMessageRect.setWidth(opt.rect.width() - presenceMessageRect.x() - rightIconsWidth);
     presenceMessageRect.setY(presenceMessageRect.y() + (presenceMessageRect.height()/2 - nameFontMetrics.height()/2));
 
     if (option.state & QStyle::State_Selected) {
